package com.ruoyi.web.modules.video.controller;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.modules.video.domain.BizLivestockMonitor;
import com.ruoyi.web.modules.video.service.IBizLivestockMonitorService;

/**
 * 畜牧监控管理
 */
@RestController
@RequestMapping("/videoSurveillance/livestockMonitor")
public class BizLivestockMonitorController extends BaseController
{
    @Autowired
    private IBizLivestockMonitorService bizLivestockMonitorService;

    @PreAuthorize("@ss.hasPermi('videoSurveillance:livestockMonitor:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizLivestockMonitor query)
    {
        startPage();
        List<BizLivestockMonitor> list = bizLivestockMonitorService.selectBizLivestockMonitorList(query);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('videoSurveillance:livestockMonitor:list')")
    @GetMapping("/ownerOptions")
    public AjaxResult ownerOptions(@RequestParam(value = "keyword", required = false) String keyword)
    {
        return success(bizLivestockMonitorService.selectOwnerOptions(keyword));
    }

    @PreAuthorize("@ss.hasPermi('videoSurveillance:livestockMonitor:query')")
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizLivestockMonitorService.selectBizLivestockMonitorById(id));
    }

    @PreAuthorize("@ss.hasPermi('videoSurveillance:livestockMonitor:add')")
    @Log(title = "畜牧监控", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody BizLivestockMonitor row)
    {
        row.setCreateBy(getUsername());
        return toAjax(bizLivestockMonitorService.insertBizLivestockMonitor(row));
    }

    @PreAuthorize("@ss.hasPermi('videoSurveillance:livestockMonitor:edit')")
    @Log(title = "畜牧监控", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody BizLivestockMonitor row)
    {
        row.setUpdateBy(getUsername());
        return toAjax(bizLivestockMonitorService.updateBizLivestockMonitor(row));
    }

    @PreAuthorize("@ss.hasPermi('videoSurveillance:livestockMonitor:remove')")
    @Log(title = "畜牧监控", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bizLivestockMonitorService.deleteBizLivestockMonitorByIds(ids, getUsername()));
    }
}
